{ config, pkgs, user, inputs, ... }:

{
  # Automatically delete generations older than a week
  nix.gc = {
    automatic = true;
    options = "--delete-generations 8d";
  };

  time.timeZone = "America/Los_Angeles";

  users.users.${user} = {
    isNormalUser = true;
    extraGroups = [ "wheel" "audio" "video" "optical" "storage" "networkmanager" ];
    initialPassword = "password";
  };

  nixpkgs.config.allowUnfree = true;

  nix = {
    package = pkgs.nixVersions.stable; # flakes
    extraOptions = "experimental-features = nix-command flakes";
  };

  networking = {
    networkmanager.enable = true;
    # networking.nameservers doesn't apply to resolvconf
    #nameservers = [ "9.9.9.9" "1.1.1.1" ];
    resolvconf.extraConfig = "name_servers=\"9.9.9.9 1.1.1.1\"";
    # Temporary since MagicDNS is broken
    hosts = {
      "192.168.0.26" = [ "elnuhub.local" ];
      "24.199.72.8" = [ "elnudrop.local" ];
      "100.64.0.1" = [ "elnu" ];
      "100.64.0.2" = [ "elnuhub" ];
      "100.64.0.3" = [ "elnudrop" ];
    };
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?
}
